@@ -894,7 +894,7 @@ def handle_raw_req(func):
 #   Fourthly, if we do have such specific package-dependent stuffs, we need to condition on existence
 class JsonRespEncoder(JSONEncoder):
     def default(self, o):
-        with ModuleNotFoundIgnore:  # added this to condition bson existence
+        with ModuleNotFoundIgnore():  # added this to condition bson existence
             from bson import ObjectId  # added this to condition bson existence
             if isinstance(o, ObjectId):
                 return str(o)
@@ -906,7 +906,7 @@ class JsonRespEncoder(JSONEncoder):
 def _mk_default_serializer_for_type():
     _serializer_for_type = {}
 
-    with ModuleNotFoundIgnore:
+    with ModuleNotFoundIgnore():
         from bson import ObjectId
         _serializer_for_type[ObjectId] = str
 
